""" Keep all attributes indexes"""
# activity calendar
CALENDAR_NAME_ACTIVE = 2
SEASON_PROFILE_ACTIVE = 3
WEEK_PROFILE_TABLE_ACTIVE = 4
DAY_PROFILE_TABLE_ACTIVE = 5
CALENDAR_NAME_PASSIVE = 6
SEASON_PROFILE_PASSIVE = 7
WEEK_PROFILE_TABLE_PASSIVE = 8
DAY_PROFILE_TABLE_PASSIVE = 9
ACTIVATE_PASSIVE_CALENDAR_TIME = 10

